==> beast-0.3.0.tar.gz: beast-0.3.0/bse/bsegentypes.c <==

/**
 ** Generated data (by mkenums.pl --interns)
 **/

/* --- bsebindata.h --- */
BseType bse_type_builtin_id_BseBinDataType = 0;

/* --- bsedefs.h --- */
BseType bse_type_builtin_id_BseDebugFlags = 0;

/* --- bseeffect.h --- */
BseType bse_type_builtin_id_BseEffectType = 0;

/* --- bseenums.h --- */
BseType bse_type_builtin_id_BseEndianType = 0;
BseType bse_type_builtin_id_BseLoopType = 0;
BseType bse_type_builtin_id_BseInstrumentType = 0;
BseType bse_type_builtin_id_BseErrorType = 0;

/* --- bsemagic.h --- */
BseType bse_type_builtin_id_BseMagicFlags = 0;

/* --- bsepcmdevice.h --- */
BseType bse_type_builtin_id_BsePcmFlags = 0;
BseType bse_type_builtin_id_BsePcmFreqMask = 0;

/* --- bsesource.h --- */
BseType bse_type_builtin_id_BseSourceFlags = 0;

/* --- bsetype.h --- */
BseType bse_type_builtin_id_BseFundamentalType = 0;

/* --- glib-extra.h --- */
BseType bse_type_builtin_id_GMatchType = 0;

/**
 ** Generated data ends here
 **/

/**
 ** Generated data (by mktypes.pl --interns --export-proto)
 **/

/* --- bsebindata.c --- */
BSE_BUILTIN_PROTO (BseBinData);
BseType bse_type_builtin_id_BseBinData = 0;

/* --- bsecontainer.c --- */
BSE_BUILTIN_PROTO (BseContainer);
BseType bse_type_builtin_id_BseContainer = 0;

/* --- bseeffect.c --- */
BSE_BUILTIN_PROTO (BseEffect);
BseType bse_type_builtin_id_BseEffect = 0;

/* --- bseeffectfinetune.c --- */
BSE_BUILTIN_PROTO (BseEffectFineTune);
BseType bse_type_builtin_id_BseEffectFineTune = 0;

/* --- bseeffectnotevolume.c --- */
BSE_BUILTIN_PROTO (BseEffectNoteVolume);
BseType bse_type_builtin_id_BseEffectNoteVolume = 0;

/* --- bseeffectpatternbreak.c --- */
BSE_BUILTIN_PROTO (BseEffectPatternBreak);
BseType bse_type_builtin_id_BseEffectPatternBreak = 0;

/* --- bseeffectpatternjump.c --- */
BSE_BUILTIN_PROTO (BseEffectPatternJump);
BseType bse_type_builtin_id_BseEffectPatternJump = 0;

/* --- bseeffectvolumedelta.c --- */
BSE_BUILTIN_PROTO (BseEffectVolumeDelta);
BseType bse_type_builtin_id_BseEffectVolumeDelta = 0;

/* --- bseglobals.c --- */
BSE_BUILTIN_PROTO (BseGConfig);
BseType bse_type_builtin_id_BseGConfig = 0;

/* --- bseheart.c --- */
BSE_BUILTIN_PROTO (BseHeart);
BseType bse_type_builtin_id_BseHeart = 0;

/* --- bseinstrument.c --- */
BSE_BUILTIN_PROTO (BseInstrument);
BseType bse_type_builtin_id_BseInstrument = 0;

/* --- bseitem.c --- */
BSE_BUILTIN_PROTO (BseItem);
BseType bse_type_builtin_id_BseItem = 0;

/* --- bsepattern.c --- */
BSE_BUILTIN_PROTO (BsePattern);
BseType bse_type_builtin_id_BsePattern = 0;

/* --- bsepcmdevice.c --- */
BSE_BUILTIN_PROTO (BsePcmDevice);
BseType bse_type_builtin_id_BsePcmDevice = 0;

/* --- bsepcmdevice-oss.c --- */
BSE_BUILTIN_PROTO (BsePcmDeviceOSS);
BseType bse_type_builtin_id_BsePcmDeviceOSS = 0;

/* --- bsepcmdevice-alsa.c --- */
BSE_BUILTIN_PROTO (BsePcmDeviceAlsa);
BseType bse_type_builtin_id_BsePcmDeviceAlsa = 0;

/* --- bseproject.c --- */
BSE_BUILTIN_PROTO (BseProject);
BseType bse_type_builtin_id_BseProject = 0;

/* --- bsesample.c --- */
BSE_BUILTIN_PROTO (BseSample);
BseType bse_type_builtin_id_BseSample = 0;

/* --- bsesnet.c --- */
BSE_BUILTIN_PROTO (BseSNet);
BseType bse_type_builtin_id_BseSNet = 0;

/* --- bsesong.c --- */
BSE_BUILTIN_PROTO (BseSong);
BseType bse_type_builtin_id_BseSong = 0;

/* --- bsesource.c --- */
BSE_BUILTIN_PROTO (BseSource);
BseType bse_type_builtin_id_BseSource = 0;

/* --- bsesuper.c --- */
BSE_BUILTIN_PROTO (BseSuper);
BseType bse_type_builtin_id_BseSuper = 0;

/**
 ** Generated data ends here
 **/

==> beast-0.3.1.tar.gz: beast-0.3.1/bse/bsegentypes.c <==

/**
 ** Generated data (by mkenums.pl)
 **/

BseType BSE_TYPE_ID (BseBinDataType) = 0;

BseType BSE_TYPE_ID (BseDebugFlags) = 0;

BseType BSE_TYPE_ID (BseDeviceFlags) = 0;

BseType BSE_TYPE_ID (BseEffectType) = 0;

BseType BSE_TYPE_ID (BseEndianType) = 0;

BseType BSE_TYPE_ID (BseLoopType) = 0;

BseType BSE_TYPE_ID (BseInstrumentType) = 0;

BseType BSE_TYPE_ID (BseErrorType) = 0;

BseType BSE_TYPE_ID (BseMagicFlags) = 0;

BseType BSE_TYPE_ID (BsePcmDeviceFlags) = 0;

BseType BSE_TYPE_ID (BsePcmFreqMask) = 0;

BseType BSE_TYPE_ID (BseSourceFlags) = 0;

BseType BSE_TYPE_ID (BseFundamentalType) = 0;

BseType BSE_TYPE_ID (GMatchType) = 0;

/**
 ** Generated data ends here
 **/

/**
 ** Generated data (by mktypes.pl --interns --export-proto)
 **/

/* --- bsebindata.c --- */
BSE_BUILTIN_PROTO (BseBinData);
BseType bse_type_builtin_id_BseBinData = 0;

/* --- bsecontainer.c --- */
BSE_BUILTIN_PROTO (BseContainer);
BseType bse_type_builtin_id_BseContainer = 0;

/* --- bsedevice.c --- */
BSE_BUILTIN_PROTO (BseDevice);
BseType bse_type_builtin_id_BseDevice = 0;

/* --- bseeffect.c --- */
BSE_BUILTIN_PROTO (BseEffect);
BseType bse_type_builtin_id_BseEffect = 0;

/* --- bseeffectfinetune.c --- */
BSE_BUILTIN_PROTO (BseEffectFineTune);
BseType bse_type_builtin_id_BseEffectFineTune = 0;

/* --- bseeffectnotevolume.c --- */
BSE_BUILTIN_PROTO (BseEffectNoteVolume);
BseType bse_type_builtin_id_BseEffectNoteVolume = 0;

/* --- bseeffectpatternbreak.c --- */
BSE_BUILTIN_PROTO (BseEffectPatternBreak);
BseType bse_type_builtin_id_BseEffectPatternBreak = 0;

/* --- bseeffectpatternjump.c --- */
BSE_BUILTIN_PROTO (BseEffectPatternJump);
BseType bse_type_builtin_id_BseEffectPatternJump = 0;

/* --- bseeffectvolumedelta.c --- */
BSE_BUILTIN_PROTO (BseEffectVolumeDelta);
BseType bse_type_builtin_id_BseEffectVolumeDelta = 0;

/* --- bsegconfig.c --- */
BSE_BUILTIN_PROTO (BseGConfig);
BseType bse_type_builtin_id_BseGConfig = 0;

/* --- bseheart.c --- */
BSE_BUILTIN_PROTO (BseHeart);
BseType bse_type_builtin_id_BseHeart = 0;

/* --- bseinstrument.c --- */
BSE_BUILTIN_PROTO (BseInstrument);
BseType bse_type_builtin_id_BseInstrument = 0;

/* --- bseitem.c --- */
BSE_BUILTIN_PROTO (BseItem);
BseType bse_type_builtin_id_BseItem = 0;

/* --- bsepattern.c --- */
BSE_BUILTIN_PROTO (BsePattern);
BseType bse_type_builtin_id_BsePattern = 0;

/* --- bsepcmdevice.c --- */
BSE_BUILTIN_PROTO (BsePcmDevice);
BseType bse_type_builtin_id_BsePcmDevice = 0;

/* --- bsepcmdevice-oss.c --- */
BSE_BUILTIN_PROTO (BsePcmDeviceOSS);
BseType bse_type_builtin_id_BsePcmDeviceOSS = 0;

/* --- bsepcmdevice-alsa.c --- */
BSE_BUILTIN_PROTO (BsePcmDeviceAlsa);
BseType bse_type_builtin_id_BsePcmDeviceAlsa = 0;

/* --- bseproject.c --- */
BSE_BUILTIN_PROTO (BseProject);
BseType bse_type_builtin_id_BseProject = 0;

/* --- bsesample.c --- */
BSE_BUILTIN_PROTO (BseSample);
BseType bse_type_builtin_id_BseSample = 0;

/* --- bsesnet.c --- */
BSE_BUILTIN_PROTO (BseSNet);
BseType bse_type_builtin_id_BseSNet = 0;

/* --- bsesong.c --- */
BSE_BUILTIN_PROTO (BseSong);
BseType bse_type_builtin_id_BseSong = 0;

/* --- bsesource.c --- */
BSE_BUILTIN_PROTO (BseSource);
BseType bse_type_builtin_id_BseSource = 0;

/* --- bsesuper.c --- */
BSE_BUILTIN_PROTO (BseSuper);
BseType bse_type_builtin_id_BseSuper = 0;

/**
 ** Generated data ends here
 **/
